@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['offset_0',['offset',['../structlibcamera_1_1FrameBuffer_1_1Plane.html#a5589ec383d6bf2b2c0612129be2f078e',1,'libcamera::FrameBuffer::Plane::offset()'],['../structlibcamera_1_1ipa__control__value__entry.html#aafaeca58cfe2244e9ddb2cefe26f2c5a',1,'libcamera::ipa_control_value_entry::offset()'],['../structlibcamera_1_1ipa__control__info__entry.html#a0708c0c2e52fd5e330056c2cb32403c6',1,'libcamera::ipa_control_info_entry::offset()']]],
+  ['offset_0',['offset',['../structlibcamera_1_1FrameBuffer_1_1Plane.html#a5589ec383d6bf2b2c0612129be2f078e',1,'libcamera::FrameBuffer::Plane::offset'],['../structlibcamera_1_1ipa__control__value__entry.html#aafaeca58cfe2244e9ddb2cefe26f2c5a',1,'libcamera::ipa_control_value_entry::offset'],['../structlibcamera_1_1ipa__control__info__entry.html#a0708c0c2e52fd5e330056c2cb32403c6',1,'libcamera::ipa_control_info_entry::offset']]],
   ['order_1',['order',['../classlibcamera_1_1BayerFormat.html#aaaff1754da78ff36513fc65a1ef6b601',1,'libcamera::BayerFormat']]],
   ['outputbufferready_2',['outputBufferReady',['../classlibcamera_1_1Converter.html#a4021a73b713028e5a1691444a98fb735',1,'libcamera::Converter']]],
   ['outputsize_3',['outputSize',['../structlibcamera_1_1IPACameraSensorInfo.html#a3843047085e7ee56ef841ac4fca31169',1,'libcamera::IPACameraSensorInfo']]]
